.. currentmodule:: typinox

API Reference
=============

.. toctree::
    :hidden:
    :maxdepth: 2

    vmapped
    typedmodule

Vmapped annotation
------------------

.. autosummary::
    :signatures: none

    VmappedT
    VmappedI
    Vmapped

Typed Modules
-------------

.. autosummary::
    :signatures: none

    TypedModule

Submodules
----------

.. toctree::
    :maxdepth: 1

    typinox.error
    typinox.shaped
    typinox.tree
